==> istio-model-v1beta1-5.11.2-sources.jar: annotations/io/fabric8/istio/api/networking/v1beta1/ClientTLSSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ClientTLSSettingsFluentImpl<A extends io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsFluent<A>{
  public ClientTLSSettingsFluentImpl() {
  }
  public ClientTLSSettingsFluentImpl(io.fabric8.istio.api.networking.v1beta1.ClientTLSSettings instance) {
    this.withCaCertificates(instance.getCaCertificates()); 
    this.withClientCertificate(instance.getClientCertificate()); 
    this.withCredentialName(instance.getCredentialName()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withMode(instance.getMode()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withSni(instance.getSni()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
  }
  private java.lang.String caCertificates;
  private java.lang.String clientCertificate;
  private java.lang.String credentialName;
  private java.lang.Boolean insecureSkipVerify;
  private io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode mode;
  private java.lang.String privateKey;
  private java.lang.String sni;
  private java.util.List<java.lang.String> subjectAltNames;
  public java.lang.String getCaCertificates() {
    return this.caCertificates;
  }
  public A withCaCertificates(java.lang.String caCertificates) {
    this.caCertificates=caCertificates; return (A) this;
  }
  public java.lang.Boolean hasCaCertificates() {
    return this.caCertificates != null;
  }
  
  /**
   * Method is deprecated. use withCaCertificates instead.
   */
  @java.lang.Deprecated
  public A withNewCaCertificates(java.lang.String arg0) {
    return (A)withCaCertificates(new String(arg0));
  }
  public java.lang.String getClientCertificate() {
    return this.clientCertificate;
  }
  public A withClientCertificate(java.lang.String clientCertificate) {
    this.clientCertificate=clientCertificate; return (A) this;
  }
  public java.lang.Boolean hasClientCertificate() {
    return this.clientCertificate != null;
  }
  
  /**
   * Method is deprecated. use withClientCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificate(java.lang.String arg0) {
    return (A)withClientCertificate(new String(arg0));
  }
  public java.lang.String getCredentialName() {
    return this.credentialName;
  }
  public A withCredentialName(java.lang.String credentialName) {
    this.credentialName=credentialName; return (A) this;
  }
  public java.lang.Boolean hasCredentialName() {
    return this.credentialName != null;
  }
  
  /**
   * Method is deprecated. use withCredentialName instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialName(java.lang.String arg0) {
    return (A)withCredentialName(new String(arg0));
  }
  public java.lang.Boolean getInsecureSkipVerify() {
    return this.insecureSkipVerify;
  }
  public A withInsecureSkipVerify(java.lang.Boolean insecureSkipVerify) {
    this.insecureSkipVerify=insecureSkipVerify; return (A) this;
  }
  public java.lang.Boolean hasInsecureSkipVerify() {
    return this.insecureSkipVerify != null;
  }
  public io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode getMode() {
    return this.mode;
  }
  public A withMode(io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public java.lang.String getPrivateKey() {
    return this.privateKey;
  }
  public A withPrivateKey(java.lang.String privateKey) {
    this.privateKey=privateKey; return (A) this;
  }
  public java.lang.Boolean hasPrivateKey() {
    return this.privateKey != null;
  }
  
  /**
   * Method is deprecated. use withPrivateKey instead.
   */
  @java.lang.Deprecated
  public A withNewPrivateKey(java.lang.String arg0) {
    return (A)withPrivateKey(new String(arg0));
  }
  public java.lang.String getSni() {
    return this.sni;
  }
  public A withSni(java.lang.String sni) {
    this.sni=sni; return (A) this;
  }
  public java.lang.Boolean hasSni() {
    return this.sni != null;
  }
  
  /**
   * Method is deprecated. use withSni instead.
   */
  @java.lang.Deprecated
  public A withNewSni(java.lang.String arg0) {
    return (A)withSni(new String(arg0));
  }
  public A addToSubjectAltNames(java.lang.Integer index,java.lang.String item) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    this.subjectAltNames.add(index, item);
    return (A)this;
  }
  public A setToSubjectAltNames(java.lang.Integer index,java.lang.String item) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    this.subjectAltNames.set(index, item); return (A)this;
  }
  public A addToSubjectAltNames(java.lang.String... items) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.subjectAltNames.add(item);} return (A)this;
  }
  public A addAllToSubjectAltNames(java.util.Collection<java.lang.String> items) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.subjectAltNames.add(item);} return (A)this;
  }
  public A removeFromSubjectAltNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.subjectAltNames!= null){ this.subjectAltNames.remove(item);}} return (A)this;
  }
  public A removeAllFromSubjectAltNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.subjectAltNames!= null){ this.subjectAltNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSubjectAltNames() {
    return this.subjectAltNames;
  }
  public java.lang.String getSubjectAltName(java.lang.Integer index) {
    return this.subjectAltNames.get(index);
  }
  public java.lang.String getFirstSubjectAltName() {
    return this.subjectAltNames.get(0);
  }
  public java.lang.String getLastSubjectAltName() {
    return this.subjectAltNames.get(subjectAltNames.size() - 1);
  }
  public java.lang.String getMatchingSubjectAltName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: subjectAltNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSubjectAltName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: subjectAltNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSubjectAltNames(java.util.List<java.lang.String> subjectAltNames) {
    if (subjectAltNames != null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : subjectAltNames){this.addToSubjectAltNames(item);}} else { this.subjectAltNames = null;} return (A) this;
  }
  public A withSubjectAltNames(java.lang.String... subjectAltNames) {
    if (this.subjectAltNames != null) {this.subjectAltNames.clear();}
    if (subjectAltNames != null) {for (java.lang.String item :subjectAltNames){ this.addToSubjectAltNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasSubjectAltNames() {
    return subjectAltNames != null && !subjectAltNames.isEmpty();
  }
  public A addNewSubjectAltName(java.lang.String arg0) {
    return (A)addToSubjectAltNames(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClientTLSSettingsFluentImpl that = (ClientTLSSettingsFluentImpl) o;
    if (caCertificates != null ? !caCertificates.equals(that.caCertificates) :that.caCertificates != null) return false;
    if (clientCertificate != null ? !clientCertificate.equals(that.clientCertificate) :that.clientCertificate != null) return false;
    if (credentialName != null ? !credentialName.equals(that.credentialName) :that.credentialName != null) return false;
    if (insecureSkipVerify != null ? !insecureSkipVerify.equals(that.insecureSkipVerify) :that.insecureSkipVerify != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (privateKey != null ? !privateKey.equals(that.privateKey) :that.privateKey != null) return false;
    if (sni != null ? !sni.equals(that.sni) :that.sni != null) return false;
    if (subjectAltNames != null ? !subjectAltNames.equals(that.subjectAltNames) :that.subjectAltNames != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCertificates,  clientCertificate,  credentialName,  insecureSkipVerify,  mode,  privateKey,  sni,  subjectAltNames,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-5.12.1-sources.jar: annotations/io/fabric8/istio/api/networking/v1beta1/ClientTLSSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ClientTLSSettingsFluentImpl<A extends io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsFluent<A>{
  public ClientTLSSettingsFluentImpl() {
  }
  public ClientTLSSettingsFluentImpl(io.fabric8.istio.api.networking.v1beta1.ClientTLSSettings instance) {
    this.withCaCertificates(instance.getCaCertificates()); 
    this.withClientCertificate(instance.getClientCertificate()); 
    this.withCredentialName(instance.getCredentialName()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withMode(instance.getMode()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withSni(instance.getSni()); 
    this.withSubjectAltNames(instance.getSubjectAltNames()); 
  }
  private java.lang.String caCertificates;
  private java.lang.String clientCertificate;
  private java.lang.String credentialName;
  private java.lang.Boolean insecureSkipVerify;
  private io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode mode;
  private java.lang.String privateKey;
  private java.lang.String sni;
  private java.util.List<java.lang.String> subjectAltNames;
  public java.lang.String getCaCertificates() {
    return this.caCertificates;
  }
  public A withCaCertificates(java.lang.String caCertificates) {
    this.caCertificates=caCertificates; return (A) this;
  }
  public java.lang.Boolean hasCaCertificates() {
    return this.caCertificates != null;
  }
  
  /**
   * Method is deprecated. use withCaCertificates instead.
   */
  @java.lang.Deprecated
  public A withNewCaCertificates(java.lang.String arg0) {
    return (A)withCaCertificates(new String(arg0));
  }
  public java.lang.String getClientCertificate() {
    return this.clientCertificate;
  }
  public A withClientCertificate(java.lang.String clientCertificate) {
    this.clientCertificate=clientCertificate; return (A) this;
  }
  public java.lang.Boolean hasClientCertificate() {
    return this.clientCertificate != null;
  }
  
  /**
   * Method is deprecated. use withClientCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificate(java.lang.String arg0) {
    return (A)withClientCertificate(new String(arg0));
  }
  public java.lang.String getCredentialName() {
    return this.credentialName;
  }
  public A withCredentialName(java.lang.String credentialName) {
    this.credentialName=credentialName; return (A) this;
  }
  public java.lang.Boolean hasCredentialName() {
    return this.credentialName != null;
  }
  
  /**
   * Method is deprecated. use withCredentialName instead.
   */
  @java.lang.Deprecated
  public A withNewCredentialName(java.lang.String arg0) {
    return (A)withCredentialName(new String(arg0));
  }
  public java.lang.Boolean getInsecureSkipVerify() {
    return this.insecureSkipVerify;
  }
  public A withInsecureSkipVerify(java.lang.Boolean insecureSkipVerify) {
    this.insecureSkipVerify=insecureSkipVerify; return (A) this;
  }
  public java.lang.Boolean hasInsecureSkipVerify() {
    return this.insecureSkipVerify != null;
  }
  public io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode getMode() {
    return this.mode;
  }
  public A withMode(io.fabric8.istio.api.networking.v1beta1.ClientTLSSettingsTLSmode mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public java.lang.String getPrivateKey() {
    return this.privateKey;
  }
  public A withPrivateKey(java.lang.String privateKey) {
    this.privateKey=privateKey; return (A) this;
  }
  public java.lang.Boolean hasPrivateKey() {
    return this.privateKey != null;
  }
  
  /**
   * Method is deprecated. use withPrivateKey instead.
   */
  @java.lang.Deprecated
  public A withNewPrivateKey(java.lang.String arg0) {
    return (A)withPrivateKey(new String(arg0));
  }
  public java.lang.String getSni() {
    return this.sni;
  }
  public A withSni(java.lang.String sni) {
    this.sni=sni; return (A) this;
  }
  public java.lang.Boolean hasSni() {
    return this.sni != null;
  }
  
  /**
   * Method is deprecated. use withSni instead.
   */
  @java.lang.Deprecated
  public A withNewSni(java.lang.String arg0) {
    return (A)withSni(new String(arg0));
  }
  public A addToSubjectAltNames(java.lang.Integer index,java.lang.String item) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    this.subjectAltNames.add(index, item);
    return (A)this;
  }
  public A setToSubjectAltNames(java.lang.Integer index,java.lang.String item) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    this.subjectAltNames.set(index, item); return (A)this;
  }
  public A addToSubjectAltNames(java.lang.String... items) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.subjectAltNames.add(item);} return (A)this;
  }
  public A addAllToSubjectAltNames(java.util.Collection<java.lang.String> items) {
    if (this.subjectAltNames == null) {this.subjectAltNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.subjectAltNames.add(item);} return (A)this;
  }
  public A removeFromSubjectAltNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.subjectAltNames!= null){ this.subjectAltNames.remove(item);}} return (A)this;
  }
  public A removeAllFromSubjectAltNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.subjectAltNames!= null){ this.subjectAltNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSubjectAltNames() {
    return this.subjectAltNames;
  }
  public java.lang.String getSubjectAltName(java.lang.Integer index) {
    return this.subjectAltNames.get(index);
  }
  public java.lang.String getFirstSubjectAltName() {
    return this.subjectAltNames.get(0);
  }
  public java.lang.String getLastSubjectAltName() {
    return this.subjectAltNames.get(subjectAltNames.size() - 1);
  }
  public java.lang.String getMatchingSubjectAltName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: subjectAltNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSubjectAltName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: subjectAltNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSubjectAltNames(java.util.List<java.lang.String> subjectAltNames) {
    if (subjectAltNames != null) {this.subjectAltNames = new java.util.ArrayList(); for (java.lang.String item : subjectAltNames){this.addToSubjectAltNames(item);}} else { this.subjectAltNames = null;} return (A) this;
  }
  public A withSubjectAltNames(java.lang.String... subjectAltNames) {
    if (this.subjectAltNames != null) {this.subjectAltNames.clear();}
    if (subjectAltNames != null) {for (java.lang.String item :subjectAltNames){ this.addToSubjectAltNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasSubjectAltNames() {
    return subjectAltNames != null && !subjectAltNames.isEmpty();
  }
  public A addNewSubjectAltName(java.lang.String arg0) {
    return (A)addToSubjectAltNames(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClientTLSSettingsFluentImpl that = (ClientTLSSettingsFluentImpl) o;
    if (caCertificates != null ? !caCertificates.equals(that.caCertificates) :that.caCertificates != null) return false;
    if (clientCertificate != null ? !clientCertificate.equals(that.clientCertificate) :that.clientCertificate != null) return false;
    if (credentialName != null ? !credentialName.equals(that.credentialName) :that.credentialName != null) return false;
    if (insecureSkipVerify != null ? !insecureSkipVerify.equals(that.insecureSkipVerify) :that.insecureSkipVerify != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (privateKey != null ? !privateKey.equals(that.privateKey) :that.privateKey != null) return false;
    if (sni != null ? !sni.equals(that.sni) :that.sni != null) return false;
    if (subjectAltNames != null ? !subjectAltNames.equals(that.subjectAltNames) :that.subjectAltNames != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caCertificates,  clientCertificate,  credentialName,  insecureSkipVerify,  mode,  privateKey,  sni,  subjectAltNames,  super.hashCode());
  }
  
}
